@@ -1,37 +1,4 @@
 # -*- coding: utf-8 -*-
-# This file is part of QuTiP: Quantum Toolbox in Python.
-#
-#    Copyright (c) 2014 and later, Alexander J G Pitchford
-#    All rights reserved.
-#
-#    Redistribution and use in source and binary forms, with or without
-#    modification, are permitted provided that the following conditions are
-#    met:
-#
-#    1. Redistributions of source code must retain the above copyright notice,
-#       this list of conditions and the following disclaimer.
-#
-#    2. Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#
-#    3. Neither the name of the QuTiP: Quantum Toolbox in Python nor the names
-#       of its contributors may be used to endorse or promote products derived
-#       from this software without specific prior written permission.
-#
-#    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-#    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-#    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-#    PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-#    HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-#    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-#    THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-#    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-#    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-###############################################################################
-
 # @author: Alexander Pitchford
 # @email1: agp1@aber.ac.uk
 # @email2: alex.pitchford@gmail.com
@@ -235,10 +202,10 @@ def optimize_pulse(
 
     method_params : dict
         Parameters for the ``optim_method``.  Note that where there is an
-        attribute of the :obj:`~Optimizer` object or the termination_conditions
-        matching the key that attribute. Otherwise, and in some case also, they
-        are assumed to be method_options for the ``scipy.optimize.minimize``
-        method.
+        attribute of the :obj:`~qutip.control.optimizer.Optimizer` object or
+        the termination_conditions matching the key that attribute.
+        Otherwise, and in some case also, they are assumed to be method_options
+        for the ``scipy.optimize.minimize`` method.
 
     optim_alg : string
         Deprecated. Use ``optim_method``.
@@ -251,35 +218,37 @@ def optimize_pulse(
 
     dyn_type : string
         Dynamics type, i.e. the type of matrix used to describe the dynamics.
-        Options are ``UNIT``, ``GEN_MAT``, ``SYMPL`` (see :obj:`~Dynamics`
-        classes for details).
+        Options are ``UNIT``, ``GEN_MAT``, ``SYMPL``
+        (see :obj:`~qutip.control.dynamics.Dynamics` classes for details).
 
     dyn_params : dict
-        Parameters for the :obj:`~Dynamics` object.  The key value pairs are
-        assumed to be attribute name value pairs.  They applied after the
-        object is created.
+        Parameters for the :obj:`~qutip.control.dynamics.Dynamics` object.
+        The key value pairs are assumed to be attribute name value pairs.
+        They applied after the object is created.
 
     prop_type : string
         Propagator type i.e. the method used to calculate the propagators and
         propagator gradient for each timeslot options are DEF, APPROX, DIAG,
         FRECHET, AUG_MAT.  DEF will use the default for the specific
-        ``dyn_type`` (see :obj:`~PropagatorComputer` classes for details).
+        ``dyn_type`` (see :obj:`~qutip.control.propcomp.PropagatorComputer`
+        classes for details).
 
     prop_params : dict
-        Parameters for the :obj:`~PropagatorComputer` object.  The key value
-        pairs are assumed to be attribute name value pairs.  They applied after
-        the object is created.
+        Parameters for the :obj:`~qutip.control.propcomp.PropagatorComputer`
+        object. The key value pairs are assumed to be attribute name value
+        pairs.  They applied after the object is created.
 
     fid_type : string
         Fidelity error (and fidelity error gradient) computation method.
         Options are DEF, UNIT, TRACEDIFF, TD_APPROX.  DEF will use the default
-        for the specific ``dyn_type`` (See :obj:`~FidelityComputer` classes for
+        for the specific ``dyn_type``
+        (See :obj:`~qutip.control.fidcomp.FidelityComputer` classes for
         details).
 
     fid_params : dict
-        Parameters for the :obj:`~FidelityComputer` object.  The key value
-        pairs are assumed to be attribute name value pairs.  They applied after
-        the object is created.
+        Parameters for the :obj:`~qutip.control.fidcomp.FidelityComputer`
+        object. The key value pairs are assumed to be attribute name value
+        pairs.  They applied after the object is created.
 
     phase_option : string
         Deprecated. Pass in ``fid_params`` instead.
@@ -290,13 +259,14 @@ def optimize_pulse(
     tslot_type : string
         Method for computing the dynamics generators, propagators and evolution
         in the timeslots.  Options: DEF, UPDATE_ALL, DYNAMIC.  UPDATE_ALL is
-        the only one that currently works.  (See :obj:`~TimeslotComputer`
-        classes for details.)
+        the only one that currently works.
+        (See :obj:`~qutip.control.tslotcomp.TimeslotComputer` classes for
+        details.)
 
     tslot_params : dict
-        Parameters for the :obj:`~TimeslotComputer` object.  The key value
-        pairs are assumed to be attribute name value pairs.  They applied after
-        the object is created.
+        Parameters for the :obj:`~qutip.control.tslotcomp.TimeslotComputer`
+        object. The key value pairs are assumed to be attribute name value
+        pairs. They applied after the object is created.
 
     amp_update_mode : string
         Deprecated. Use ``tslot_type`` instead.
@@ -304,8 +274,8 @@ def optimize_pulse(
     init_pulse_type : string
         Type / shape of pulse(s) used to initialise the control amplitudes.
         Options (GRAPE) include: RND, LIN, ZERO, SINE, SQUARE, TRIANGLE, SAW.
-        Default is RND.  (see :obj:`~PulseGen` classes for details.) For the
-        CRAB the this the ``guess_pulse_type``.
+        Default is RND. (see :obj:`~qutip.control.pulsegen.PulseGen` classes
+        for details). For the CRAB the this the ``guess_pulse_type``.
 
     init_pulse_params : dict
         Parameters for the initial / guess pulse generator object.
@@ -353,9 +323,9 @@ def optimize_pulse(
     Returns
     -------
     opt : OptimResult
-        Returns instance of :obj:`~OptimResult`, which has attributes giving
-        the reason for termination, final fidelity error, final evolution final
-        amplitudes, statistics etc.
+        Returns instance of :obj:`~qutip.control.optimresult.OptimResult`,
+        which has attributes giving the reason for termination, final fidelity
+        error, final evolution final amplitudes, statistics etc.
     """
     if log_level == logging.NOTSET:
         log_level = logger.getEffectiveLevel()
@@ -614,10 +584,10 @@ def optimize_pulse_unitary(
 
     method_params : dict
         Parameters for the ``optim_method``.  Note that where there is an
-        attribute of the :obj:`~Optimizer` object or the
-        ``termination_conditions`` matching the key that attribute. Otherwise,
-        and in some case also, they are assumed to be method_options for the
-        ``scipy.optimize.minimize`` method.
+        attribute of the :obj:`~qutip.control.optimizer.Optimizer` object or
+        the ``termination_conditions`` matching the key that attribute.
+        Otherwise, and in some case also, they are assumed to be
+        method_options for the ``scipy.optimize.minimize`` method.
 
     optim_alg : string
         Deprecated. Use ``optim_method``.
@@ -636,30 +606,30 @@ def optimize_pulse_unitary(
         - SU - global phase included
 
     dyn_params : dict
-        Parameters for the :obj:`~Dynamics` object.  The key value pairs are
-        assumed to be attribute name value pairs.  They applied after the
-        object is created.
+        Parameters for the :obj:`~qutip.control.dynamics.Dynamics` object.
+        The key value pairs are assumed to be attribute name value pairs.
+        They applied after the object is created.
 
     prop_params : dict
-        Parameters for the :obj:`~PropagatorComputer` object.  The key value
-        pairs are assumed to be attribute name value pairs.  They applied after
-        the object is created.
+        Parameters for the :obj:`~qutip.control.propcomp.PropagatorComputer`
+        object. The key value pairs are assumed to be attribute name value
+        pairs.  They applied after the object is created.
 
     fid_params : dict
-        Parameters for the :obj:`~FidelityComputer` object.  The key value
-        pairs are assumed to be attribute name value pairs.  They applied after
-        the object is created.
+        Parameters for the :obj:`~qutip.control.fidcomp.FidelityComputer`
+        object. The key value pairs are assumed to be attribute name value
+        pairs.  They applied after the object is created.
 
     tslot_type : string
         Method for computing the dynamics generators, propagators and evolution
         in the timeslots.  Options: ``DEF``, ``UPDATE_ALL``, ``DYNAMIC``.
         ``UPDATE_ALL`` is the only one that currently works.  (See
-        :obj:`~TimeslotComputer` classes for details.)
+        :obj:`~qutip.control.tslotcomp.TimeslotComputer` classes for details.)
 
     tslot_params : dict
-        Parameters for the :obj:`~TimeslotComputer` object.  The key value
-        pairs are assumed to be attribute name value pairs.  They applied after
-        the object is created.
+        Parameters for the :obj:`~qutip.control.tslotcomp.TimeslotComputer`
+        object. The key value pairs are assumed to be attribute name value
+        pairs.  They applied after the object is created.
 
     amp_update_mode : string
         Deprecated. Use ``tslot_type`` instead.
@@ -667,8 +637,8 @@ def optimize_pulse_unitary(
     init_pulse_type : string
         Type / shape of pulse(s) used to initialise the control amplitudes.
         Options (GRAPE) include: RND, LIN, ZERO, SINE, SQUARE, TRIANGLE, SAW.
-        DEF is RND.  (see :obj:`~PulseGen` classes for details.) For the CRAB
-        the this the guess_pulse_type.
+        DEF is RND.  (see :obj:`~qutip.control.pulsegen.PulseGen` classes for
+        details.) For the CRAB the this the guess_pulse_type.
 
     init_pulse_params : dict
         Parameters for the initial / guess pulse generator object.  The key
@@ -716,9 +686,9 @@ def optimize_pulse_unitary(
     Returns
     -------
     opt : OptimResult
-        Returns instance of :obj:`~OptimResult`, which has attributes giving
-        the reason for termination, final fidelity error, final evolution final
-        amplitudes, statistics etc.
+        Returns instance of :obj:`~qutip.control.optimresult.OptimResult`,
+        which has attributes giving the reason for termination, final fidelity
+        error, final evolution final amplitudes, statistics etc.
     """
 
     # parameters are checked in create pulse optimiser
@@ -782,7 +752,8 @@ def optimize_pulse_unitary(
             optim_method=optim_method, method_params=method_params,
             dyn_type='UNIT', dyn_params=dyn_params,
             prop_params=prop_params, fid_params=fid_params,
-            init_pulse_type=init_pulse_type, init_pulse_params=init_pulse_params,
+            init_pulse_type=init_pulse_type,
+            init_pulse_params=init_pulse_params,
             pulse_scaling=pulse_scaling, pulse_offset=pulse_offset,
             ramping_pulse_type=ramping_pulse_type,
             ramping_pulse_params=ramping_pulse_params,
@@ -897,10 +868,10 @@ def opt_pulse_crab(
 
     method_params : dict
         Parameters for the optim_method.  Note that where there is an attribute
-        of the :obj:`~Optimizer` object or the termination_conditions matching
-        the key that attribute. Otherwise, and in some case also, they are
-        assumed to be method_options for the ``scipy.optimize.minimize``
-        method.  The commonly used parameter are:
+        of the :class:`~qutip.control.optimizer.Optimizer` object or the
+        termination_conditions matching the key that attribute. Otherwise,
+        and in some case also, they are assumed to be method_options for the
+        ``scipy.optimize.minimize`` method.  The commonly used parameter are:
 
         - xtol - limit on variable change for convergence
         - ftol - limit on fidelity error change for convergence
@@ -910,42 +881,45 @@ def opt_pulse_crab(
         Options are UNIT, GEN_MAT, SYMPL (see Dynamics classes for details).
 
     dyn_params : dict
-        Parameters for the Dynamics object.  The key value pairs are assumed to
-        be attribute name value pairs.  They applied after the object is
-        created.
+        Parameters for the :class:`qutip.control.dynamics.Dynamics` object.
+        The key value pairs are assumed to be attribute name value pairs.
+        They applied after the object is created.
 
     prop_type : string
         Propagator type i.e. the method used to calculate the propagtors and
         propagtor gradient for each timeslot options are DEF, APPROX, DIAG,
         FRECHET, AUG_MAT DEF will use the default for the specific dyn_type
-        (see :obj:`~PropagatorComputer` classes for details).
+        (see :obj:`~qutip.control.propcomp.PropagatorComputer` classes for
+        details).
 
     prop_params : dict
-        Parameters for the :obj:`~PropagatorComputer` object.  The key value
-        pairs are assumed to be attribute name value pairs.  They applied after
-        the object is created.
+        Parameters for the :obj:`~qutip.control.propcomp.PropagatorComputer`
+        object. The key value pairs are assumed to be attribute name value
+        pairs. They applied after the object is created.
 
     fid_type : string
         Fidelity error (and fidelity error gradient) computation method.
         Options are DEF, UNIT, TRACEDIFF, TD_APPROX.  DEF will use the default
-        for the specific dyn_type.  (See :obj:`~FidelityComputer` classes for
+        for the specific dyn_type.
+        (See :obj:`~qutip.control.fidcomp.FidelityComputer` classes for
         details).
 
     fid_params : dict
-        Parameters for the :obj:`~FidelityComputer` object.  The key value
-        pairs are assumed to be attribute name value pairs.  They applied after
-        the object is created.
+        Parameters for the :obj:`~qutip.control.fidcomp.FidelityComputer`
+        object. The key value pairs are assumed to be attribute name value
+        pairs. They applied after the object is created.
 
     tslot_type : string
         Method for computing the dynamics generators, propagators and evolution
         in the timeslots.  Options: DEF, UPDATE_ALL, DYNAMIC UPDATE_ALL is the
-        only one that currently works.  (See :obj:`~TimeslotComputer` classes
+        only one that currently works.
+        (See :obj:`~qutip.control.tslotcomp.TimeslotComputer` classes
         for details).
 
     tslot_params : dict
-        Parameters for the :obj:`~TimeslotComputer` object.  The key value
-        pairs are assumed to be attribute name value pairs.  They applied after
-        the object is created.
+        Parameters for the :obj:`~qutip.control.tslotcomp.TimeslotComputer`
+        object. The key value pairs are assumed to be attribute name value
+        pairs. They applied after the object is created.
 
     guess_pulse_type : string, default None
         Type / shape of pulse(s) used modulate the control amplitudes.
@@ -1171,10 +1145,10 @@ def opt_pulse_crab_unitary(
 
     method_params : dict
         Parameters for the ``optim_method``.  Note that where there is an
-        attribute of the :obj:`~Optimizer` object or the termination_conditions
-        matching the key that attribute. Otherwise, and in some case also, they
-        are assumed to be method_options for the ``scipy.optimize.minimize``
-        method.  The commonly used parameter are:
+        attribute of the :obj:`~qutip.control.optimizer.Optimizer` object or
+        the termination_conditions matching the key that attribute. Otherwise,
+        and in some case also, they are assumed to be method_options for the
+        ``scipy.optimize.minimize`` method.  The commonly used parameter are:
 
         - xtol - limit on variable change for convergence
         - ftol - limit on fidelity error change for convergence
@@ -1187,30 +1161,31 @@ def opt_pulse_crab_unitary(
         - SU - global phase included
 
     dyn_params : dict
-        Parameters for the :obj:`~Dynamics` object.  The key value pairs are
-        assumed to be attribute name value pairs.  They applied after the
-        object is created.
+        Parameters for the :obj:`~qutip.control.dynamics.Dynamics` object.
+        The key value pairs are assumed to be attribute name value pairs.
+        They applied after the object is created.
 
     prop_params : dict
-        Parameters for the :obj:`~PropagatorComputer` object.  The key value
-        pairs are assumed to be attribute name value pairs.  They applied after
-        the object is created.
+        Parameters for the :obj:`~qutip.control.propcomp.PropagatorComputer`
+        object. The key value pairs are assumed to be attribute name value
+        pairs.  They applied after the object is created.
 
     fid_params : dict
-        Parameters for the :obj:`~FidelityComputer` object.  The key value
-        pairs are assumed to be attribute name value pairs.  They applied after
-        the object is created.
+        Parameters for the :obj:`~qutip.control.fidcomp.FidelityComputer`
+        object. The key value pairs are assumed to be attribute name value
+        pairs. They applied after the object is created.
 
     tslot_type : string
         Method for computing the dynamics generators, propagators and evolution
         in the timeslots.  Options: DEF, UPDATE_ALL, DYNAMIC.  UPDATE_ALL is
-        the only one that currently works.  (See :obj:`~TimeslotComputer`
-        classes for details).
+        the only one that currently works.
+        (See :obj:`~qutip.control.tslotcomp.TimeslotComputer` classes for
+        details).
 
     tslot_params : dict
-        Parameters for the :obj:`~TimeslotComputer` object The key value pairs
-        are assumed to be attribute name value pairs. They applied after the
-        object is created.
+        Parameters for the :obj:`~qutip.control.tslotcomp.TimeslotComputer`
+        object. The key value pairs are assumed to be attribute name value
+        pairs. They applied after the object is created.
 
     guess_pulse_type : string, optional
         Type / shape of pulse(s) used modulate the control amplitudes.
@@ -1266,9 +1241,9 @@ def opt_pulse_crab_unitary(
     Returns
     -------
     opt : OptimResult
-        Returns instance of :obj:`~OptimResult`, which has attributes giving
-        the reason for termination, final fidelity error, final evolution final
-        amplitudes, statistics etc.
+        Returns instance of :obj:`~qutip.control.optimresult.OptimResult`,
+        which has attributes giving the reason for termination, final fidelity
+        error, final evolution final amplitudes, statistics etc.
     """
 
     # The parameters are checked in create_pulse_optimizer
@@ -1436,9 +1411,9 @@ def create_pulse_optimizer(
     method_params : dict
         Parameters for the optim_method.
         Note that where there is an attribute of the
-        Optimizer object or the termination_conditions matching the key
-        that attribute. Otherwise, and in some case also,
-        they are assumed to be method_options
+        :class:`~qutip.control.optimizer.Optimizer` object or the
+        termination_conditions matching the key that attribute. Otherwise,
+        and in some case also, they are assumed to be method_options
         for the scipy.optimize.minimize method.
 
     optim_alg : string
@@ -1497,9 +1472,9 @@ def create_pulse_optimizer(
         (See TimeslotComputer classes for details)
 
     tslot_params : dict
-        Parameters for the TimeslotComputer object
-        The key value pairs are assumed to be attribute name value pairs
-        They applied after the object is created
+        Parameters for the TimeslotComputer object.
+        The key value pairs are assumed to be attribute name value pairs.
+        They applied after the object is created.
 
     amp_update_mode : string
         Deprecated. Use tslot_type instead.
@@ -1516,9 +1491,9 @@ def create_pulse_optimizer(
         For the CRAB the this the guess_pulse_type.
 
     init_pulse_params : dict
-        Parameters for the initial / guess pulse generator object
-        The key value pairs are assumed to be attribute name value pairs
-        They applied after the object is created
+        Parameters for the initial / guess pulse generator object.
+        The key value pairs are assumed to be attribute name value pairs.
+        They applied after the object is created.
 
     pulse_scaling : float
         Linear scale factor for generated initial / guess pulses
@@ -1537,8 +1512,8 @@ def create_pulse_optimizer(
         GAUSSIAN_EDGE was added for this purpose.
 
     ramping_pulse_params : dict
-        Parameters for the ramping pulse generator object
-        The key value pairs are assumed to be attribute name value pairs
+        Parameters for the ramping pulse generator object.
+        The key value pairs are assumed to be attribute name value pairs.
         They applied after the object is created
 
     log_level : integer
@@ -1563,8 +1538,9 @@ def create_pulse_optimizer(
         Config, Dynamics, PulseGen, and TerminationConditions objects
         can be accessed as attributes.
         The PropagatorComputer, FidelityComputer and TimeslotComputer objects
-        can be accessed as attributes of the Dynamics object, e.g. optimizer.dynamics.fid_computer
-        The optimisation can be run through the optimizer.run_optimization
+        can be accessed as attributes of the Dynamics object,
+        e.g. optimizer.dynamics.fid_computer The optimisation can be run
+        through the optimizer.run_optimization
 
     """
 
