@@ -1,36 +1,3 @@
-# This file is part of QuTiP: Quantum Toolbox in Python.
-#
-#    Copyright (c) 2011 and later, Paul D. Nation and Robert J. Johansson.
-#    All rights reserved.
-#
-#    Redistribution and use in source and binary forms, with or without
-#    modification, are permitted provided that the following conditions are
-#    met:
-#
-#    1. Redistributions of source code must retain the above copyright notice,
-#       this list of conditions and the following disclaimer.
-#
-#    2. Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#
-#    3. Neither the name of the QuTiP: Quantum Toolbox in Python nor the names
-#       of its contributors may be used to endorse or promote products derived
-#       from this software without specific prior written permission.
-#
-#    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-#    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-#    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-#    PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-#    HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-#    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-#    THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-#    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-#    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-###############################################################################
-
 __all__ = ['correlation_2op_1t', 'correlation_2op_2t', 'correlation_3op_1t',
            'correlation_3op_2t', 'coherence_function_g1',
            'coherence_function_g2', 'spectrum', 'spectrum_correlation_fft',
@@ -1102,18 +1069,15 @@ def _correlation_me_2t(H, state0, tlist, taulist, c_ops, a_op, b_op, c_op,
     rho_t = mesolve(H, rho0, tlist, c_ops, [],
                     args=args, options=options).states
     corr_mat = np.zeros([np.size(tlist), np.size(taulist)], dtype=complex)
-    H_shifted, c_ops_shifted, _args = _transform_L_t_shift_new(H, c_ops, args)
+    taulist = np.asarray(taulist)
     if config.tdname:
         _cython_build_cleanup(config.tdname)
     rhs_clear()
 
     for t_idx, rho in enumerate(rho_t):
-        if not isinstance(H, Qobj):
-            _args["_t0"] = tlist[t_idx]
-
         corr_mat[t_idx, :] = mesolve(
-            H_shifted, c_op * rho * a_op, taulist, c_ops_shifted,
-            [b_op], args=_args, options=options
+            H, c_op * rho * a_op, taulist + tlist[t_idx], c_ops,
+            [b_op], args=args, options=options
         ).expect[0]
 
         if t_idx == 1:
@@ -1238,7 +1202,8 @@ def _correlation_mc_2t(H, state0, tlist, taulist, c_ops, a_op, b_op, c_op,
     ).states
 
     corr_mat = np.zeros([np.size(tlist), np.size(taulist)], dtype=complex)
-    H_shifted, c_ops_shifted, _args = _transform_L_t_shift_new(H, c_ops, args)
+    tlist = np.asarray(tlist)
+    taulist = np.asarray(taulist)
     if config.tdname:
         _cython_build_cleanup(config.tdname)
     rhs_clear()
@@ -1246,9 +1211,6 @@ def _correlation_mc_2t(H, state0, tlist, taulist, c_ops, a_op, b_op, c_op,
     # calculation of <A(t)B(t+tau)C(t)> from only knowledge of psi0 requires
     # averaging over both t and tau
     for t_idx in range(np.size(tlist)):
-        if not isinstance(H, Qobj):
-            _args["_t0"] = tlist[t_idx]
-
         for trial_idx in range(options.ntraj[0]):
             if isinstance(a_op, Qobj) and isinstance(c_op, Qobj):
                 if a_op.dag() == c_op:
@@ -1258,9 +1220,9 @@ def _correlation_mc_2t(H, state0, tlist, taulist, c_ops, a_op, b_op, c_op,
 
                     # evolve these states and calculate expectation value of B
                     c_tau = chi_0.norm()**2 * mcsolve(
-                        H_shifted, chi_0/chi_0.norm(), taulist, c_ops_shifted,
+                        H, chi_0/chi_0.norm(), taulist + tlist[t_idx], c_ops,
                         [b_op],
-                        args=_args, ntraj=options.ntraj[1], options=options,
+                        args=args, ntraj=options.ntraj[1], options=options,
                         progress_bar=None
                     ).expect[0]
 
@@ -1285,9 +1247,9 @@ def _correlation_mc_2t(H, state0, tlist, taulist, c_ops, a_op, b_op, c_op,
                 # evolve these states and calculate expectation value of B
                 c_tau = [
                     chi.norm()**2 * mcsolve(
-                        H_shifted, chi/chi.norm(), taulist, c_ops_shifted,
+                        H, chi/chi.norm(), taulist + tlist[t_idx], c_ops,
                         [b_op],
-                        args=_args, ntraj=options.ntraj[1], options=options,
+                        args=args, ntraj=options.ntraj[1], options=options,
                         progress_bar=None
                     ).expect[0]
                     for chi in chi_0
@@ -1349,55 +1311,3 @@ def _spectrum_pi(H, wlist, c_ops, a_op, b_op, use_pinv=False):
         spectrum[idx] = -2 * np.real(s[0, 0])
 
     return spectrum
-
-
-# auxiliary
-def _transform_shift_one_coeff(op, args):
-    if isinstance(op, types.FunctionType):
-        # function-list based time-dependence
-        if isinstance(args, dict):
-            def fn(t, args_i):
-                return op(t + args_i["_t0"], args_i)
-            fn = lambda t, args_i: \
-                op(t + args_i["_t0"], args_i)
-        else:
-            def fn(t, args_i):
-                return op(t + args_i["_t0"], args_i["_user_args"])
-    else:
-        fn = sub("(?<=[^0-9a-zA-Z_])t(?=[^0-9a-zA-Z_])",
-                 "(t+_t0)", " " + op + " ")
-    return fn
-
-
-def _transform_shift_one_op(op, args={}):
-    if isinstance(op, Qobj):
-        new_op = op
-    elif isinstance(op, QobjEvo):
-        new_op = op
-        new_op._shift
-    elif callable(op):
-        def new_op(t, args_i):
-            return op(t + args_i["_t0"], args_i)
-    elif isinstance(op, list):
-        new_op = []
-        for block in op:
-            if isinstance(block, list):
-                new_op.append([block[0],
-                               _transform_shift_one_coeff(block[1], args)])
-            else:
-                new_op.append(block)
-    return new_op
-
-
-def _transform_L_t_shift_new(H, c_ops, args={}):
-    H_shifted = _transform_shift_one_op(H, args)
-    c_ops_shifted = [_transform_shift_one_op(op, args) for op in c_ops]
-    if args is None:
-        _args = {"_t0": 0}
-    elif isinstance(args, dict):
-        _args = args.copy()
-        _args["_t0"] = 0
-    else:
-        _args = {"_user_args": args, "_t0": 0}
-
-    return H_shifted, c_ops_shifted, _args
