@@ -131,8 +131,8 @@ def measurement_statistics_povm(state, ops, targets=None):
 
     targets : list of ints, optional
               Specifies a list of target "qubit" indices on which to apply
-              the measurement using qutip.qip.gates.expand_operator to expand
-              ops into full dimension.
+              the measurement using qutip.qip.operations.gates.expand_operator
+              to expand ops into full dimension.
 
 
     Returns
@@ -182,8 +182,8 @@ def measurement_statistics_observable(state, op, targets=None):
 
     targets : list of ints, optional
         Specifies a list of targets "qubit" indices on which to apply the
-        measurement using :func:`qutip.qip.gates.expand_operator` to expand op
-        into full dimension.
+        measurement using :func:`qutip.qip.operations.gates.expand_operator`
+        to expand op into full dimension.
 
     Returns
     -------
@@ -234,8 +234,8 @@ def measure_observable(state, op, targets=None):
 
     targets : list of ints, optional
         Specifies a list of target "qubit" indices on which to apply the
-        measurement using :func:`qutip.qip.gates.expand_operator` to expand op
-        into full dimension.
+        measurement using :func:`qutip.qip.operations.gates.expand_operator`
+        to expand op into full dimension.
 
     Returns
     -------
@@ -321,7 +321,8 @@ def measure_povm(state, ops, targets=None):
 
     targets : list of ints, optional
         Specifies a list of target "qubit" indices on which to apply
-        the measurement using :func:`qutip.qip.gates.expand_operator`
+        the measurement using
+        :func:`qutip.qip.operations.gates.expand_operator`
         to expand ``ops`` into full dimension.
 
     Returns
@@ -367,8 +368,8 @@ def measurement_statistics(state, ops, targets=None):
 
     targets : list of ints, optional
         Specifies a list of target "qubit" indices on which to apply the
-        measurement using :func:`qutip.qip.gates.expand_operator` to expand ops
-        into full dimension.
+        measurement using :func:`qutip.qip.operations.gates.expand_operator`
+        to expand ops into full dimension.
     """
     if isinstance(ops, list):
         return measurement_statistics_povm(state, ops, targets)
@@ -404,8 +405,8 @@ def measure(state, ops, targets=None):
 
     targets : list of ints, optional
         Specifies a list of target "qubit" indices on which to apply the
-        measurement using :func:`qutip.qip.gates.expand_operator` to expand ops
-        into full dimension.
+        measurement using :func:`qutip.qip.operations.gates.expand_operator`
+        to expand ops into full dimension.
     """
     if isinstance(ops, list):
         return measure_povm(state, ops, targets)
