@@ -1,35 +1,3 @@
-# This file is part of QuTiP: Quantum Toolbox in Python.
-#
-#    Copyright (c) 2011 and later, Paul D. Nation and Robert J. Johansson.
-#    All rights reserved.
-#
-#    Redistribution and use in source and binary forms, with or without
-#    modification, are permitted provided that the following conditions are
-#    met:
-#
-#    1. Redistributions of source code must retain the above copyright notice,
-#       this list of conditions and the following disclaimer.
-#
-#    2. Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#
-#    3. Neither the name of the QuTiP: Quantum Toolbox in Python nor the names
-#       of its contributors may be used to endorse or promote products derived
-#       from this software without specific prior written permission.
-#
-#    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-#    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-#    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-#    PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-#    HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-#    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-#    THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-#    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-#    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-###############################################################################
 """
 This module contains functions for generating Qobj representation of a variety
 of commonly occuring quantum operators.
@@ -645,7 +613,7 @@ def squeeze(N, z, offset=0):
 
     Returns
     -------
-    oper : :class:`qutip.qobj.Qobj`
+    oper : :class:`qutip.Qobj`
         Squeezing operator.
 
 
@@ -676,10 +644,10 @@ def squeezing(a1, a2, z):
 
     Parameters
     ----------
-    a1 : :class:`qutip.qobj.Qobj`
+    a1 : :class:`qutip.Qobj`
         Operator 1.
 
-    a2 : :class:`qutip.qobj.Qobj`
+    a2 : :class:`qutip.Qobj`
         Operator 2.
 
     z : float/complex
@@ -687,7 +655,7 @@ def squeezing(a1, a2, z):
 
     Returns
     -------
-    oper : :class:`qutip.qobj.Qobj`
+    oper : :class:`qutip.Qobj`
         Squeezing operator.
 
     """
@@ -891,7 +859,7 @@ def enr_destroy(dims, excitations):
     a_ops = [sp.lil_matrix((nstates, nstates), dtype=np.complex128)
              for _ in range(len(dims))]
 
-    for n1, state1 in idx2state.items():
+    for n1, state1 in enumerate(idx2state):
         for idx, s in enumerate(state1):
             # if s > 0, the annihilation operator of mode idx has a non-zero
             # entry with one less excitation in mode idx in the final state
