@@ -1,42 +1,10 @@
-# This file is part of QuTiP: Quantum Toolbox in Python.
-#
-#    Copyright (c) 2011 and later, Paul D. Nation and Robert J. Johansson.
-#    All rights reserved.
-#
-#    Redistribution and use in source and binary forms, with or without
-#    modification, are permitted provided that the following conditions are
-#    met:
-#
-#    1. Redistributions of source code must retain the above copyright notice,
-#       this list of conditions and the following disclaimer.
-#
-#    2. Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#
-#    3. Neither the name of the QuTiP: Quantum Toolbox in Python nor the names
-#       of its contributors may be used to endorse or promote products derived
-#       from this software without specific prior written permission.
-#
-#    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-#    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-#    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-#    PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-#    HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-#    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-#    THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-#    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-#    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-###############################################################################
 """
 This function provides functions for parallel execution of loops and function
 mappings, using the builtin Python module multiprocessing.
 """
 __all__ = ['parfor', 'parallel_map', 'serial_map']
 
-from scipy import array
+from numpy import array
 import multiprocessing
 from functools import partial
 import os
@@ -76,7 +44,7 @@ def parfor(func, *args, **kwargs):
 
     .. note::
 
-        From QuTiP 3.1, we recommend to use :func:`qutip.parallel_map`
+        From QuTiP 3.1, we recommend to use :func:`qutip.parallel.parallel_map`
         instead of this function.
 
     Parameters
@@ -151,7 +119,8 @@ def serial_map(task, values, task_args=tuple(), task_kwargs={}, **kwargs):
 
         result = [task(value, *task_args, **task_kwargs) for value in values]
 
-    This function work as a drop-in replacement of :func:`qutip.parallel_map`.
+    This function work as a drop-in replacement of
+    :func:`qutip.parallel.parallel_map`.
 
     Parameters
     ----------
