@@ -50,7 +50,7 @@ _fredkin_like = ["FREDKIN"]
 
 class Gate:
     """
-    Representation of a quantum gate, with its required parametrs, and target
+    Representation of a quantum gate, with its required parameters, and target
     and control qubits.
 
     Parameters
@@ -442,7 +442,7 @@ class QubitCircuit:
 
         Parameters
         ----------
-        name: string
+        measurement: string
             Measurement name. If name is an instance of `Measuremnent`,
             parameters are unpacked and added.
         targets: list
@@ -493,7 +493,8 @@ class QubitCircuit:
         arg_label: string
             Label for gate representation.
         index : list
-            Positions to add the gate.
+            Positions to add the gate. Each index in the supplied list refers
+            to a position in the original list of gates.
         classical_controls : int or list of int, optional
             indices of classical bits to control gate on.
         control_value : int, optional
@@ -524,9 +525,10 @@ class QubitCircuit:
             self.gates.append(gate)
 
         else:
-            for position in index:
-                num_mes = (sum(isinstance(op, Measurement) for op
-                               in self.gates[:position]))
+            # NOTE: Every insertion shifts the indices in the original list of
+            #       gates by an additional position to the right.
+            shifted_inds = np.sort(index) + np.arange(len(index))
+            for position in shifted_inds:
                 gate = Gate(name, targets=targets, controls=controls,
                             arg_value=arg_value, arg_label=arg_label,
                             classical_controls=classical_controls,
@@ -556,8 +558,7 @@ class QubitCircuit:
         arg_label : string
             Label for gate representation.
         """
-        if name not in ["RX", "RY", "RZ", "SNOT", "SQRTNOT", "PHASEGATE",
-                        "X", "Y", "Z", "S", "T", "QASMU"]:
+        if name not in _single_qubit_gates:
             raise ValueError("%s is not a single qubit gate" % name)
 
         if qubits is not None:
@@ -578,7 +579,7 @@ class QubitCircuit:
                             control_value=control_value)
                 self.gates.append(gate)
 
-    def add_circuit(self, qc, start=0):
+    def add_circuit(self, qc, start=0, overwrite_user_gates=False):
         """
         Adds a block of a qubit circuit to the main circuit.
         Globalphase gates are not added.
@@ -593,47 +594,36 @@ class QubitCircuit:
         if self.N - start < qc.N:
             raise NotImplementedError("Targets exceed number of qubits.")
 
+        # Inherit the user gates
+        for user_gate in qc.user_gates:
+            if user_gate in self.user_gates and not overwrite_user_gates:
+                continue
+            self.user_gates[user_gate] = qc.user_gates[user_gate]
+
         for circuit_op in qc.gates:
 
             if isinstance(circuit_op, Gate):
-                gate = circuit_op
 
-                if gate.name in ["RX", "RY", "RZ",
-                                 "SNOT", "SQRTNOT", "PHASEGATE", "QASMU"]:
-                    self.add_gate(gate.name, gate.targets[0] + start, None,
-                                  gate.arg_value, gate.arg_label)
-                elif gate.name in ["X", "Y", "Z", "S", "T"]:
-                    self.add_gate(gate.name, gate.targets[0] + start, None,
-                                  None, gate.arg_label)
-                elif gate.name in ["CPHASE", "CNOT", "CSIGN", "CRX", "CRY",
-                                   "CRZ", "CY", "CZ", "CS", "CT"]:
-                    self.add_gate(gate.name, gate.targets[0] + start,
-                                  gate.controls[0] + start, gate.arg_value,
-                                  gate.arg_label)
-                elif gate.name in ["BERKELEY", "SWAPalpha", "SWAP", "ISWAP",
-                                   "SQRTSWAP", "SQRTISWAP"]:
-                    self.add_gate(gate.name,
-                                  [gate.targets[0] + start,
-                                   gate.targets[1] + start])
-                elif gate.name in ["TOFFOLI"]:
-                    self.add_gate(gate.name, gate.targets[0] + start,
-                                  [gate.controls[0] + start,
-                                   gate.controls[1] + start], None, None)
-                elif gate.name in ["FREDKIN"]:
-                    self.add_gate(gate.name,
-                                  [gate.targets[0] + start,
-                                   gate.targets[1] + start],
-                                  gate.controls + start, None, None)
-                elif gate.name in self.user_gates:
-                    self.add_gate(
-                        gate.name, targets=gate.targets,
-                        arg_value=gate.arg_value)
-            else:
-                measurement = circuit_op
+                if circuit_op.targets is not None:
+                    tar = [target + start for target in circuit_op.targets]
+                else:
+                    tar = None
+                if circuit_op.controls is not None:
+                    ctrl = [control + start for control in circuit_op.controls]
+                else:
+                    ctrl = None
+
+                self.add_gate(
+                    circuit_op.name, targets=tar, controls=ctrl,
+                    arg_value=circuit_op.arg_value)
+            elif isinstance(circuit_op, Measurement):
                 self.add_measurement(
-                                measurement.name,
-                                targets=[measurement.targets[0] + start],
-                                classical_store=measurement.classical_store)
+                    circuit_op.name,
+                    targets=[target + start for target in circuit_op.targets],
+                    classical_store=circuit_op.classical_store)
+            else:
+                raise TypeError("The circuit to be added contains unknown \
+                    operator {}".format(circuit_op))
 
     def remove_gate_or_measurement(self, index=None, end=None,
                                    name=None, remove="first"):
@@ -1624,7 +1614,7 @@ class QubitCircuit:
             elif gate.name == "TOFFOLI":
                 self.U_list.append(toffoli())
             elif gate.name == "GLOBALPHASE":
-                self.U_list.append(globalphase(gate.arg_value, n))
+                self.U_list.append(globalphase(gate.arg_value))
             elif gate.name in self.user_gates:
                 if gate.controls is not None:
                     raise ValueError("A user defined gate {} takes only  "
