@@ -1,4 +1,4 @@
-__all__ = ['rhs_generate', 'rhs_clear']
+__all__ = ['rhs_clear']
 
 import os
 import numpy as np
@@ -37,167 +37,6 @@ def rhs_clear():
     if "mcsolve" in solver_safe:
         del solver_safe["mcsolve"]
 
-def rhs_generate(H, c_ops, args={}, options=Options(), name=None,
-                 cleanup=True):
-    """
-    Generates the Cython functions needed for solving the dynamics of a
-    given system using the mesolve function inside a parfor loop.
-
-    Parameters
-    ----------
-    H : qobj
-        System Hamiltonian.
-
-    c_ops : list
-        ``list`` of collapse operators.
-
-    args : dict
-        Arguments for time-dependent Hamiltonian and collapse operator terms.
-
-    options : Options
-        Instance of ODE solver options.
-
-    name: str
-        Name of generated RHS
-
-    cleanup: bool
-        Whether the generated cython file should be automatically removed or
-        not.
-
-    Notes
-    -----
-    Using this function with any solver other than the mesolve function
-    will result in an error.
-
-    """
-    config.reset()
-    config.options = options
-
-    if name:
-        config.tdname = name
-    else:
-        config.tdname = "rhs" + str(os.getpid()) + str(config.cgen_num)
-
-    Lconst = 0
-
-    Ldata = []
-    Linds = []
-    Lptrs = []
-    Lcoeff = []
-    Lobj = []
-
-    # loop over all hamiltonian terms, convert to superoperator form and
-    # add the data of sparse matrix represenation to
-
-    msg = "Incorrect specification of time-dependence: "
-
-    for h_spec in H:
-        if isinstance(h_spec, Qobj):
-            h = h_spec
-
-            if not isinstance(h, Qobj):
-                raise TypeError(msg + "expected Qobj")
-
-            if h.isoper:
-                Lconst += -1j * (spre(h) - spost(h))
-            elif h.issuper:
-                Lconst += h
-            else:
-                raise TypeError(msg + "expected operator or superoperator")
-
-        elif isinstance(h_spec, list):
-            h = h_spec[0]
-            h_coeff = h_spec[1]
-
-            if not isinstance(h, Qobj):
-                raise TypeError(msg + "expected Qobj")
-
-            if h.isoper:
-                L = -1j * (spre(h) - spost(h))
-            elif h.issuper:
-                L = h
-            else:
-                raise TypeError(msg + "expected operator or superoperator")
-
-            Ldata.append(L.data.data)
-            Linds.append(L.data.indices)
-            Lptrs.append(L.data.indptr)
-            if isinstance(h_coeff, Cubic_Spline):
-                Lobj.append(h_coeff.coeffs)
-            Lcoeff.append(h_coeff)
-
-        else:
-            raise TypeError(msg + "expected string format")
-
-    # loop over all collapse operators
-    for c_spec in c_ops:
-        if isinstance(c_spec, Qobj):
-            c = c_spec
-
-            if not isinstance(c, Qobj):
-                raise TypeError(msg + "expected Qobj")
-
-            if c.isoper:
-                cdc = c.dag() * c
-                Lconst += spre(c) * spost(c.dag()) - 0.5 * spre(cdc) \
-                                                   - 0.5 * spost(cdc)
-            elif c.issuper:
-                Lconst += c
-            else:
-                raise TypeError(msg + "expected operator or superoperator")
-
-        elif isinstance(c_spec, list):
-            c = c_spec[0]
-            c_coeff = c_spec[1]
-
-            if not isinstance(c, Qobj):
-                raise TypeError(msg + "expected Qobj")
-
-            if c.isoper:
-                cdc = c.dag() * c
-                L = spre(c) * spost(c.dag()) - 0.5 * spre(cdc) \
-                                             - 0.5 * spost(cdc)
-                c_coeff = "(" + c_coeff + ")**2"
-            elif c.issuper:
-                L = c
-            else:
-                raise TypeError(msg + "expected operator or superoperator")
-
-            Ldata.append(L.data.data)
-            Linds.append(L.data.indices)
-            Lptrs.append(L.data.indptr)
-            Lcoeff.append(c_coeff)
-
-        else:
-            raise TypeError(msg + "expected string format")
-
-    # add the constant part of the lagrangian
-    if Lconst != 0:
-        Ldata.append(Lconst.data.data)
-        Linds.append(Lconst.data.indices)
-        Lptrs.append(Lconst.data.indptr)
-        Lcoeff.append("1.0")
-
-    # the total number of liouvillian terms (hamiltonian terms + collapse
-    # operators)
-    n_L_terms = len(Ldata)
-
-    cgen = Codegen(h_terms=n_L_terms, h_tdterms=Lcoeff, args=args,
-                   config=config)
-    cgen.generate(config.tdname + ".pyx")
-
-    code = compile('from ' + config.tdname +
-                   ' import cy_td_ode_rhs', '<string>', 'exec')
-    exec(code, globals())
-
-    config.tdfunc = cy_td_ode_rhs
-
-    if cleanup:
-        try:
-            os.remove(config.tdname + ".pyx")
-        except:
-            pass
-
 
 def _td_format_check(H, c_ops, solver='me'):
     """
