@@ -1,35 +1,3 @@
-# This file is part of QuTiP: Quantum Toolbox in Python.
-#
-#    Copyright (c) 2011 and later, Paul D. Nation and Robert J. Johansson,
-#    All rights reserved.
-#
-#    Redistribution and use in source and binary forms, with or without
-#    modification, are permitted provided that the following conditions are
-#    met:
-#
-#    1. Redistributions of source code must retain the above copyright notice,
-#       this list of conditions and the following disclaimer.
-#
-#    2. Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#
-#    3. Neither the name of the QuTiP: Quantum Toolbox in Python nor the names
-#       of its contributors may be used to endorse or promote products derived
-#       from this software without specific prior written permission.
-#
-#    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-#    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-#    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-#    PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-#    HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-#    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-#    THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-#    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-#    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-###############################################################################
 from __future__ import print_function
 
 __all__ = ['Options', 'Odeoptions', 'Odedata', 'ExpectOps']
@@ -75,14 +43,26 @@ class ExpectOps:
         self.e_ops = e_ops
         if isinstance(e_ops, list):
             self.e_num = len(e_ops)
-            self.e_ops_isherm = [e.isherm for e in e_ops]
-            if not super_:
-                self.e_ops_qoevo = np.array([QobjEvo(e) for e in e_ops],
-                                            dtype=object)
-            else:
-                self.e_ops_qoevo = np.array([QobjEvo(spre(e)) for e in e_ops],
-                                            dtype=object)
-            [op.compile() for op in self.e_ops_qoevo]
+            e_ops_qoevo = []
+            e_ops_isherm = []
+            for e in e_ops:
+                if isinstance(e, (Qobj, QobjEvo)):
+                    e_ops_isherm.append(e.isherm)
+                    e_ops_qoevo_entry = None
+                    if not super_:
+                        e_ops_qoevo_entry = QobjEvo(e)
+                    else:
+                        e_ops_qoevo_entry = QobjEvo(spre(e))
+                    e_ops_qoevo_entry.compile()
+                    e_ops_qoevo.append(e_ops_qoevo_entry)
+                elif callable(e):
+                    e_ops_isherm.append(None)
+                    e_ops_qoevo.append(e)
+                else:
+                    raise TypeError("Expectation value list entry needs to be "
+                                    "either a function either an operator")
+            self.e_ops_isherm = e_ops_isherm
+            self.e_ops_qoevo = np.array(e_ops_qoevo, dtype=object)
         elif callable(e_ops):
             self.isfunc = True
             self.e_num = 1
@@ -118,8 +98,12 @@ class ExpectOps:
         else:
             t = self.tlist[iter_]
             for ii in range(self.e_num):
-                self.raw_out[ii, iter_] = \
-                    self.e_ops_qoevo[ii].compiled_qobjevo.expect(t, state)
+                if isinstance(self.e_ops_qoevo[ii], QobjEvo):
+                    self.raw_out[ii, iter_] = \
+                        self.e_ops_qoevo[ii].compiled_qobjevo.expect(t, state)
+                elif callable(self.e_ops_qoevo[ii]):
+                    self.raw_out[ii, iter_] = \
+                        self.e_ops_qoevo[ii](t, state)
 
     def finish(self):
         if self.isfunc:
