@@ -1,36 +1,3 @@
-# This file is part of QuTiP: Quantum Toolbox in Python.
-#
-#    Copyright (c) 2011 and later, Paul D. Nation and Robert J. Johansson.
-#    All rights reserved.
-#
-#    Redistribution and use in source and binary forms, with or without
-#    modification, are permitted provided that the following conditions are
-#    met:
-#
-#    1. Redistributions of source code must retain the above copyright notice,
-#       this list of conditions and the following disclaimer.
-#
-#    2. Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#
-#    3. Neither the name of the QuTiP: Quantum Toolbox in Python nor the names
-#       of its contributors may be used to endorse or promote products derived
-#       from this software without specific prior written permission.
-#
-#    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-#    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-#    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-#    PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-#    HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-#    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-#    THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-#    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-#    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-###############################################################################
-
 __all__ = ['basis', 'qutrit_basis', 'coherent', 'coherent_dm', 'fock_dm',
            'fock', 'thermal_dm', 'maximally_mixed_dm', 'ket2dm', 'projection',
            'qstate', 'ket', 'bra', 'state_number_enumerate',
@@ -42,8 +9,9 @@ __all__ = ['basis', 'qutrit_basis', 'coherent', 'coherent_dm', 'fock_dm',
 
 import numbers
 import numpy as np
-from numpy import arange, conj, prod
+from numpy import arange, conj
 import scipy.sparse as sp
+import itertools
 
 from qutip.qobj import Qobj
 from qutip.operators import destroy, jmat
@@ -168,7 +136,7 @@ def qutrit_basis():
     return out
 
 
-def coherent(N, alpha, offset=0, method='operator'):
+def coherent(N, alpha, offset=0, method=None):
     """Generates a coherent state with eigenvalue alpha.
 
     Constructed using displacement operator on vacuum state.
@@ -218,14 +186,24 @@ def coherent(N, alpha, offset=0, method='operator'):
     but would in that case give more accurate coefficients.
 
     """
-    if method == "operator" and offset == 0:
+    if offset < 0:
+        raise ValueError('Offset must be non-negative')
 
+    if method is None:
+        method = "operator" if offset == 0 else "analytic"
+
+    if method == "operator":
+        if offset != 0:
+            raise ValueError(
+                "The method 'operator' does not support offset != 0. Please"
+                " select another method or set the offset to zero."
+            )
         x = basis(N, 0)
         a = destroy(N)
         D = (alpha * a.dag() - conj(alpha) * a).expm()
         return D * x
 
-    elif method == "analytic" or offset > 0:
+    elif method == "analytic":
         sqrtn = np.sqrt(np.arange(offset, offset+N, dtype=complex))
         sqrtn[0] = 1  # Get rid of divide by zero warning
         data = alpha/sqrtn
@@ -242,7 +220,7 @@ def coherent(N, alpha, offset=0, method='operator'):
             "The method option can only take values 'operator' or 'analytic'")
 
 
-def coherent_dm(N, alpha, offset=0, method='operator'):
+def coherent_dm(N, alpha, offset=0, method=None):
     """Density matrix representation of a coherent state.
 
     Constructed via outer product of :func:`qutip.states.coherent`
@@ -748,67 +726,62 @@ def bra(seq, dim=2):
 #
 # quantum state number helper functions
 #
-def state_number_enumerate(dims, excitations=None, state=None, idx=0, nexc=0):
+def state_number_enumerate(dims, excitations=None):
     """
-    An iterator that enumerate all the state number arrays (quantum numbers on
-    the form [n1, n2, n3, ...]) for a system with dimensions given by dims.
+    An iterator that enumerates all the state number tuples (quantum numbers of
+    the form (n1, n2, n3, ...)) for a system with dimensions given by dims.
 
     Example:
 
         >>> for state in state_number_enumerate([2,2]): # doctest: +SKIP
         >>>     print(state) # doctest: +SKIP
-        [ 0  0 ]
-        [ 0  1 ]
-        [ 1  0 ]
-        [ 1  1 ]
+        ( 0  0 )
+        ( 0  1 )
+        ( 1  0 )
+        ( 1  1 )
 
     Parameters
     ----------
     dims : list or array
         The quantum state dimensions array, as it would appear in a Qobj.
 
-    state : list
-        Current state in the iteration. Used internally.
-
     excitations : integer (None)
         Restrict state space to states with excitation numbers below or
         equal to this value.
 
-    idx : integer
-        Current index in the iteration. Used internally.
-
-    nexc : integer
-        Number of excitations in modes [0..idx-1]. Used internally.
-
     Returns
     -------
-    state_number : list
-        Successive state number arrays that can be used in loops and other
+    state_number : tuple
+        Successive state number tuples that can be used in loops and other
         iterations, using standard state enumeration *by definition*.
 
     """
 
-    if state is None:
-        state = np.zeros(len(dims), dtype=int)
+    if excitations is None:
+        # in this case, state numbers are a direct product
+        yield from itertools.product(*(range(d) for d in dims))
+        return
 
-    if idx == len(dims):
-        if excitations is None:
-            yield np.array(state)
-        else:
-            yield tuple(state)
-    else:
-        if excitations is None:
-            nlim = dims[idx]
-        else:
-            # modes [0..idx-1] have nexc excitations,
-            # so mode idx can have at most excitations-nexc excitations
-            nlim = min(dims[idx], 1 + excitations - nexc)
+    # From here on, excitations is not None
 
-        for n in range(nlim):
-            state[idx] = n
-            for s in state_number_enumerate(dims, excitations,
-                                            state, idx + 1, nexc + n):
-                yield s
+    # General idea of algorithm: add excitations one by one in last mode (idx =
+    # len(dims)-1), and carry over to the next index when the limit is reached.
+    # Keep track of the number of excitations while doing so to avoid having to
+    # do explicit sums over the states.
+    state = (0,)*len(dims)
+    nexc = 0
+    while True:
+        yield state
+        idx = len(dims) - 1
+        state = state[:idx] + (state[idx]+1,)
+        nexc += 1
+        while nexc > excitations or state[idx] >= dims[idx]:
+            # remove all excitations in mode idx, add one in idx-1
+            idx -= 1
+            if idx < 0:
+                return
+            nexc -= state[idx+1] - 1
+            state = state[:idx] + (state[idx]+1, 0) + state[idx+2:]
 
 
 def state_number_index(dims, state):
@@ -836,8 +809,7 @@ def state_number_index(dims, state):
         ordering.
 
     """
-    return int(
-        sum([state[i] * prod(dims[i + 1:]) for i, d in enumerate(dims)]))
+    return np.ravel_multi_index(state, dims)
 
 
 def state_index_number(dims, index):
@@ -860,20 +832,12 @@ def state_index_number(dims, index):
 
     Returns
     -------
-    state : list
-        The state number array corresponding to index `index` in standard
+    state : tuple
+        The state number tuple corresponding to index `index` in standard
         enumeration ordering.
 
     """
-    state = np.empty_like(dims)
-
-    D = np.concatenate([np.flipud(np.cumprod(np.flipud(dims[1:]))), [1]])
-
-    for n in range(len(dims)):
-        state[n] = index / D[n]
-        index -= state[n] * D[n]
-
-    return list(state)
+    return np.unravel_index(index, dims)
 
 
 def state_number_qobj(dims, state):
@@ -906,12 +870,13 @@ shape = [8, 1], type = ket
 
     Returns
     -------
-    state : :class:`qutip.Qobj.qobj`
-        The state as a :class:`qutip.Qobj.qobj` instance.
+    state : :class:`qutip.Qobj`
+        The state as a :class:`qutip.Qobj` instance.
 
 
     """
-    return tensor([fock(dims[i], s) for i, s in enumerate(state)])
+    assert len(state) == len(dims)
+    return tensor([fock(d, s) for d, s in zip(dims, state)])
 
 
 #
@@ -933,19 +898,16 @@ def enr_state_dictionaries(dims, excitations):
 
     Returns
     -------
-    nstates, state2idx, idx2state: integer, dict, dict
+    nstates, state2idx, idx2state: integer, dict, list
         The number of states `nstates`, a dictionary for looking up state
-        indices from a state tuple, and a dictionary for looking up state
-        state tuples from state indices.
+        indices from a state tuple, and a list containing the state tuples
+        ordered by state indices. state2idx and idx2state are reverses of
+        each other, i.e., state2idx[idx2state[idx]] = idx and
+        idx2state[state2idx[state]] = state.
     """
-    nstates = 0
-    state2idx = {}
-    idx2state = {}
-
-    for state in state_number_enumerate(dims, excitations):
-        state2idx[state] = nstates
-        idx2state[nstates] = state
-        nstates += 1
+    idx2state = list(state_number_enumerate(dims, excitations))
+    state2idx = {state: idx for idx, state in enumerate(idx2state)}
+    nstates = len(idx2state)
 
     return nstates, state2idx, idx2state
 
@@ -986,7 +948,7 @@ def enr_fock(dims, excitations, state):
 
     try:
         data[state2idx[tuple(state)], 0] = 1
-    except:
+    except Exception:
         raise ValueError("The state tuple %s is not in the restricted "
                          "state space" % str(tuple(state)))
 
@@ -1029,8 +991,7 @@ def enr_thermal_dm(dims, excitations, n):
     else:
         n = np.asarray(n)
 
-    diags = [np.prod((n / (n + 1)) ** np.array(state))
-             for idx, state in idx2state.items()]
+    diags = [np.prod((n / (n + 1)) ** np.array(state)) for state in idx2state]
     diags /= np.sum(diags)
     data = sp.spdiags(diags, 0, nstates, nstates, format='csr')
 
