@@ -190,30 +190,47 @@ def choi_to_kraus(q_oper, tol=1e-9):
     TODO: Create a new class structure for quantum channels, perhaps as a
     strict sub-class of Qobj.
     """
-    vals, vecs = eig(q_oper.full())
-    vecs = [array(_) for _ in zip(*vecs)]
-    shape = [np.prod(q_oper.dims[0][i]) for i in range(2)][::-1]
-    return [Qobj(inpt=sqrt(val)*vec2mat(vec, shape=shape),
-            dims=q_oper.dims[0][::-1])
-            for val, vec in zip(vals, vecs) if abs(val) >= tol]
+    vals, vecs = q_oper.eigenstates(phase_fix=0)
+    elements_to_keep = abs(vals) >= tol
+    sqrt_vals, vecs = np.sqrt(vals[elements_to_keep]), vecs[elements_to_keep]
+    shape = (np.prod(q_oper.dims[0][1]), np.prod(q_oper.dims[0][0]))
+    dims = q_oper.dims[0][::-1]
+    return [
+        Qobj(inpt=sqrt_val * vec.data.reshape(shape, order="F"), dims=dims)
+        for sqrt_val, vec in zip(sqrt_vals, vecs)
+    ]
 
 
-def kraus_to_choi(kraus_list):
+def kraus_to_choi(kraus_ops):
+    r"""
+    Convert a list of Kraus operators into Choi representation of the channel.
+
+    Essentially, kraus operators are a decomposition of a Choi matrix,
+    so in this function we build Choi matrix from vector representation of Kraus operators.
+
+    Parameters
+    ----------
+    kraus_ops : list[Qobj]
+        The list of Kraus operators to be converted to Choi representation.
+
+    Returns
+    -------
+    choi : Qobj
+        A quantum object representing the same map as ``kraus_ops``, such that
+        ``choi.superrep == "choi"``.
     """
-    Takes a list of Kraus operators and returns the Choi matrix for the channel
-    represented by the Kraus operators in `kraus_list`
-    """
-    kraus_mat_list = list(map(lambda x: x.data.toarray(), kraus_list))
-    op_rng = range(kraus_mat_list[0].shape[0])
-    choi_blocks = array([[sum([
-                              np.outer(op[:, c_ix],
-                                       np.transpose(np.conjugate(op))[r_ix, :])
-                              for op in kraus_mat_list])
-                          for r_ix in op_rng]
-                         for c_ix in op_rng])
-    return Qobj(inpt=hstack(hstack(choi_blocks)),
-                dims=[kraus_list[0].dims[::-1], kraus_list[0].dims[::-1]],
-                type='super', superrep='choi')
+    len_op = np.prod(kraus_ops[0].shape)
+    # If Kraus ops have dims [M, N] in qutip notation (act on [N, N] density matrix and produce [M, M] d.m.),
+    # Choi matrix Hilbert space will be [[M, N], [M, N]] because Choi Hilbert space is (output space) x (input space).
+    choi_dims = [kraus_ops[0].dims] * 2
+    # transform a list of Qobj matrices list[sum_ij k_ij |i><j|]
+    # into an array of array vectors sum_ij k_ij |i, j>> = sum_I k_I |I>>
+    kraus_vectors = np.asarray(
+        [np.reshape(kraus_op.full(), len_op, "F") for kraus_op in kraus_ops]
+    )
+    # sum_{I} |k_I|^2 |I>><<I|
+    choi_array = np.tensordot(kraus_vectors, kraus_vectors.conj(), axes=([0], [0]))
+    return Qobj(choi_array, choi_dims, superrep="choi", copy=False)
 
 
 def kraus_to_super(kraus_list):
@@ -224,7 +241,7 @@ def kraus_to_super(kraus_list):
 
 
 def _nq(dims):
-    dim = np.product(dims[0][0])
+    dim = np.prod(dims[0][0])
     nq = int(log2(dim))
     if 2 ** nq != dim:
         raise ValueError("{} is not an integer power of 2.".format(dim))
