@@ -179,7 +179,7 @@ class TestHierarchyADOsState:
 
     def mk_rho_and_soln(self, ados, rho_dims):
         n_ados = len(ados.labels)
-        ado_soln = np.random.rand(n_ados, *[np.product(d) for d in rho_dims])
+        ado_soln = np.random.rand(n_ados, *[np.prod(d) for d in rho_dims])
         rho = Qobj(ado_soln[0, :], dims=rho_dims)
         return rho, ado_soln
 
