@@ -1,35 +1,3 @@
-# This file is part of QuTiP: Quantum Toolbox in Python.
-#
-#    Copyright (c) 2011 and later, The QuTiP Project.
-#    All rights reserved.
-#
-#    Redistribution and use in source and binary forms, with or without
-#    modification, are permitted provided that the following conditions are
-#    met:
-#
-#    1. Redistributions of source code must retain the above copyright notice,
-#       this list of conditions and the following disclaimer.
-#
-#    2. Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#
-#    3. Neither the name of the QuTiP: Quantum Toolbox in Python nor the names
-#       of its contributors may be used to endorse or promote products derived
-#       from this software without specific prior written permission.
-#
-#    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-#    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-#    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-#    PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-#    HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-#    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-#    THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-#    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-#    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-###############################################################################
 import numpy as np
 import pytest
 import qutip
@@ -241,26 +209,29 @@ class TestLattice1d:
                 else:
                     kop[row, col] = 1 / (np.exp(2j * np.pi * (row - col)/L)-1)
         kt = np.kron(kop * 2 * np.pi / L, np.eye(6))
-        dim_H = [[2, 2, 3], [2, 2, 3]]
+        dim_H = [[L, 2, 3], [L, 2, 3]]
         kt = qutip.Qobj(kt, dims=dim_H)
         k_q = kq.eigenstates()[0]
         k_t = kt.eigenstates()[0]
         k_tC = k_t - (2*np.pi/L) * ((L-1) // 2)
         np.testing.assert_allclose(k_tC, k_q, atol=1e-12)
 
-    @pytest.mark.parametrize(["lattice", "k_expected", "energies_expected"], [
-        pytest.param(qutip.Lattice1d(num_cell=8),
+    @pytest.mark.parametrize([
+        "lattice_func", "k_expected", "energies_expected",
+    ], [
+        pytest.param(lambda: qutip.Lattice1d(num_cell=8),
                      _k_expected(8),
                      np.array([[2, np.sqrt(2), 0, -np.sqrt(2), -2,
                                 -np.sqrt(2), 0, np.sqrt(2)]]),
                      id="atom chain"),
-        pytest.param(_ssh_lattice(-0.5, -0.6,
-                                  cells=6, sites_per_cell=2, freedom=[2, 2]),
+        pytest.param(lambda: _ssh_lattice(
+                        -0.5, -0.6, cells=6, sites_per_cell=2, freedom=[2, 2]),
                      _k_expected(6),
                      np.array([-_ssh_energies]*4 + [_ssh_energies]*4),
                      id="ssh model")
     ])
-    def test_get_dispersion(self, lattice, k_expected, energies_expected):
+    def test_get_dispersion(self, lattice_func, k_expected, energies_expected):
+        lattice = lattice_func()
         k_test, energies_test = lattice.get_dispersion()
         _assert_angles_close(k_test, k_expected, atol=1e-8)
         np.testing.assert_allclose(energies_test, energies_expected, atol=1e-8)
