@@ -1,36 +1,4 @@
 # -*- coding: utf-8 -*-
-# This file is part of QuTiP: Quantum Toolbox in Python.
-#
-#    Copyright (c) 2011 and later, Paul D. Nation and Robert J. Johansson.
-#    All rights reserved.
-#
-#    Redistribution and use in source and binary forms, with or without
-#    modification, are permitted provided that the following conditions are
-#    met:
-#
-#    1. Redistributions of source code must retain the above copyright notice,
-#       this list of conditions and the following disclaimer.
-#
-#    2. Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#
-#    3. Neither the name of the QuTiP: Quantum Toolbox in Python nor the names
-#       of its contributors may be used to endorse or promote products derived
-#       from this software without specific prior written permission.
-#
-#    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-#    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-#    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-#    PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-#    HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-#    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-#    THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-#    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-#    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-###############################################################################
 
 import platform
 
@@ -45,6 +13,13 @@ from qutip import (
 from qutip.qip.operations import (
     hadamard_transform, swap,
 )
+
+try:
+    import cvxpy
+    import cvxopt
+except ImportError:
+    cvxpy, cvxopt = None, None
+
 # These ones are the metrics functions that we actually want to test.
 from qutip import (
     fidelity, tracedist, hellinger_dist, dnorm, average_gate_fidelity,
@@ -310,13 +285,24 @@ def adc_choi(x):
 # is failing every time, but not penalise one-off failures.  As far as we know,
 # the failing tests always involve a random step, so triggering a re-run will
 # have them choose new variables as well.
+#
+# The warning filter is to account for cvxpy < 1.1.10 which uses np.complex,
+# which is deprecated as of numpy 1.20.
+#
+# Skip dnorm tests if we don't have cvxpy or cvxopt available, since dnorm
+# depends on them.
+@pytest.mark.skipif(cvxpy is None or cvxopt is None,
+                    reason="Skipping dnorm tests because dnorm requires cvxpy"
+                    " and cvxopt which are not installed.")
+@pytest.mark.skipif("Windows" in platform.system(),
+                    reason="Skipping dnorm tests -- cvxpy and cvxopt can be"
+                    " installed on Windows but fail to correctly solve"
+                    " the given optimization problems.")
 @pytest.mark.flaky(reruns=2)
+@pytest.mark.filterwarnings(
+    "ignore:`np.complex` is a deprecated alias:DeprecationWarning:cvxpy"
+)
 class Test_dnorm:
-    # Skip dnorm tests if we don't have cvxpy or cvxopt available, since it
-    # depends on them.
-    cvxpy = pytest.importorskip("cvxpy")
-    cvxopt = pytest.importorskip("cvxopt")
-
     @pytest.fixture(params=[2, 3])
     def dimension(self, request):
         return request.param
