@@ -1,11 +1,11 @@
 import numpy as np
-from numpy.testing import assert_equal, assert_, run_module_suite
+from numpy.testing import assert_equal, assert_
 import unittest
 from qutip import *
 import qutip.settings as qset
 if qset.has_openmp:
     from qutip.cy.openmp.benchmark import _spmvpy, _spmvpy_openmp
-    
+
 
 @unittest.skipIf(qset.has_openmp == False, 'OPENMP not available.')
 def test_openmp_spmv():
@@ -51,7 +51,7 @@ def test_openmp_mesolve():
     rate = gamma
     if rate > 0.0:
         c_op_list.append(np.sqrt(rate) * sm)
-    
+
     n = N - 2
     psi0 = tensor(basis(N, n), basis(2, 1))
     tlist = np.linspace(0, 1, 100)
@@ -80,9 +80,9 @@ def test_openmp_mesolve_td():
     # Hamiltonian
     H0 = wc * a.dag() * a + wa * sm.dag() * sm
     H1 = g * (a.dag() + a) * (sm + sm.dag())
-    
+
     H = [H0, [H1,'sin(t)']]
-    
+
     c_op_list = []
 
     rate = kappa * (1 + n_th_a)
@@ -96,7 +96,7 @@ def test_openmp_mesolve_td():
     rate = gamma
     if rate > 0.0:
         c_op_list.append(np.sqrt(rate) * sm)
-    
+
     n = N - 10
     psi0 = tensor(basis(N, n), basis(2, 1))
     tlist = np.linspace(0, 1, 100)
@@ -106,6 +106,3 @@ def test_openmp_mesolve_td():
     out = mesolve(H, psi0, tlist, c_op_list, [a.dag() * a, sm.dag() * sm], options=opts)
     assert_(np.allclose(out.expect[0],out_omp.expect[0]))
     assert_(np.allclose(out.expect[1],out_omp.expect[1]))
-
-if __name__ == "__main__":
-    run_module_suite()
