@@ -4,7 +4,6 @@ Tests for Permutational Invariant Quantum solver (PIQS).
 import numpy as np
 from numpy.testing import (
     assert_,
-    run_module_suite,
     assert_raises,
     assert_array_equal,
     assert_array_almost_equal,
@@ -1534,7 +1533,3 @@ class TestPim:
         no_hamiltonian_system = Dicke(4, emission=0.1)
         result = no_hamiltonian_system.pisolve(diag_initial_state, tlist)
         assert_equal(True, len(result.states) > 0)
-
-
-if __name__ == "__main__":
-    run_module_suite()
